@@ -26,16 +26,16 @@ const ws = host.replace("http", "ws");
 const app = "satteldruckanalyse";
 
 var sessionID;
-if(localStorage.getItem('session')){
-    if(localStorage.getItem('session').split(" ")[0]=='restart'){
-        sessionID = localStorage.getItem('session').split(" ")[1]
+if(getFromLocalStorage('session')){
+    if(getFromLocalStorage('session').split(" ")[0]=='restart'){
+        sessionID = getFromLocalStorage('session').split(" ")[1]
     } 
 } else {
-    sessionID = localStorage.getItem('new_session')
+    sessionID = getFromLocalStorage('new_session')
 }
 
-if(localStorage.getItem('sessionID')){
-    sessionID = localStorage.getItem('sessionID')
+if(getFromLocalStorage('sessionID')){
+    sessionID = getFromLocalStorage('sessionID')
 }
 try {
   var sattelanalyse = new WebSocket(`${ws}/apps/${app}`, ["soap", "wamp"]);
@@ -67,9 +67,9 @@ _satteldruckanalyse();
  * It gets the name from local storage and puts it in the right places
  */
 function _name() {
-  let name = localStorage.getItem("client_name").split(" ");
+  let name = getFromLocalStorage("client_name").split(" ");
   let infos = document.getElementById('galerie_info');
-  infos.innerHTML = `${name[1]} ${name[0]} - ${localStorage.getItem('session_note')||""}`;
+  infos.innerHTML = `${name[1]} ${name[0]} - ${getFromLocalStorage('session_note')||""}`;
 
 }
 
@@ -143,7 +143,7 @@ sattelanalyse.onmessage = (e) => {
     // let a = document.getElementsByClassName('imgGal2')[fi-1];
     sda_frame3 = `${host}/sattelbild?image=sda_int3&rnd=${new Date().getTime()}`;
     img.src = sda_frame3;
-    img.setAttribute("onclick", `OpenChart(${recID[fi - 1]})`);
+    img.setAttribute("onclick", `OpenChart(${recID[fi - 1]});hide()`);
     img.id = recID[fi - 1];
     recData[recID[fi - 1]] = JSON.stringify(galerie_image_info);
     // a.setAttribute('onclick',`sattelanalyse.send('recording retrieve ${recID[fi-1]} ${load_num}')`)
@@ -398,7 +398,7 @@ function OpenChart(id) {
  * The function `PDFgenGal` generates a PDF document containing a gallery of images.
  */
 function PDFgenGal(){
-    let name = localStorage.getItem('client_name').split(' ')
+    let name = getFromLocalStorage('client_name').split(' ')
 
     var content = [
         {text: `${aLangKeys[lang]['pro_tab_galerie']} - ${name[1]} ${name[0]}`, style: 'header'},
@@ -414,9 +414,9 @@ function PDFgenGal(){
   content.push({text:`${aLangKeys[lang]['pro_tab_galerie']}`,style:['header','bold','center']})
   //content.push({text:`${aLangKeys[lang]['pro_head']}`,style:['header','bold','center']})
   content.push('\n')
-  content.push({text:`${localStorage.getItem('client_forenames')} ${localStorage.getItem('client_surename')}`, style: ['XXL','bold','center']})
-  if(localStorage.getItem('session_note') !== ''){
-    content.push({text:`${localStorage.getItem('session_note')}`, style: ['bigger','bold','center']})   
+  content.push({text:`${getFromLocalStorage('client_forenames')} ${getFromLocalStorage('client_surename')}`, style: ['XXL','bold','center']})
+  if(getFromLocalStorage('session_note') !== ''){
+    content.push({text:`${getFromLocalStorage('session_note')}`, style: ['bigger','bold','center']})   
   }
   content.push({text:`${new Date().toISOString().split('T')[0]}`,style:['small','center']})
   content.push('\n')
@@ -624,7 +624,7 @@ function PDFgenGal(){
             { text:`${mail} | ${web}`,style:['right','XXS'],margin:[40,0]},
           //  { text:"",style:['right'],margin:[40,0]},
             { text:`Bike Fitter: ${name2}`,style:['right','XXS'],margin:[40,0]},
-            { text:`${localStorage.getItem('client_forenames')} ${localStorage.getItem('client_surename')}`,style:['left','bigger','bold'],margin:[40,0]},
+            { text:`${getFromLocalStorage('client_forenames')} ${getFromLocalStorage('client_surename')}`,style:['left','bigger','bold'],margin:[40,0]},
             { text:`${aLangKeys[lang]['pro_bikefit']} ${aLangKeys[lang]['pro_head']} ${new Date().toISOString().split('T')[0]}`,style:['left','XXS'],margin:[40,0]}
             
           //  {canvas: [ { type: 'line', x1: 40, y1: 0, x2: 515, y2: 0, lineWidth: 1 } ]}
@@ -861,7 +861,7 @@ function setChartType(params) {
  */
 function ClientInfo(params) {
     onsqlresult = getLog;
-    localStorage.setItem('client_info',JSON.stringify(params));
+    saveToLocalStorage('client_info',JSON.stringify(params));
   }
   /**
    * It takes three arguments, sends a query to the database, and then creates a table with the results
@@ -874,12 +874,12 @@ function ClientInfo(params) {
     onsqlresult = ClientInfo
     sattelanalyse.send(`sql select * from sessions where client_id=${client_id}`);
     let inter = setInterval(()=> {
-        localStorage.setItem('client_fc',fc)
-        localStorage.setItem('client_name',name)
-        localStorage.setItem('client_mail',mail)
-        localStorage.setItem('client_id',client_id)
-        localStorage.setItem('client_forenames',fname)
-        localStorage.setItem('client_surename',lname)
+        saveToLocalStorage('client_fc',fc)
+        saveToLocalStorage('client_name',name)
+        saveToLocalStorage('client_mail',mail)
+        saveToLocalStorage('client_id',client_id)
+        saveToLocalStorage('client_forenames',fname)
+        saveToLocalStorage('client_surename',lname)
         location.href = "/production/client.tcls"
         clearInterval(inter);
       }, 500);
