@@ -2167,4 +2167,67 @@ function CheckOnline(data) {
 function delNextCheck() {
   delete script_setting.nextcheck;
   saveConfig(); // Speichert die Änderungen, falls erforderlich
-}
\ No newline at end of file
+}
+
+/**
+ * The function `downloadJSON` takes JSON data, converts it into a formatted string, creates a
+ * downloadable JSON file, and triggers the download in the browser.
+ * @param filename - The `filename` parameter is a string that represents the name you want to give to
+ * the downloaded JSON file. For example, if you want to download a file named "data.json", you would
+ * pass "data.json" as the `filename` parameter when calling the `downloadJSON` function.
+ * @param jsonData - The `jsonData` parameter in the `downloadJSON` function is the JSON data that you
+ * want to download as a file. It should be a JavaScript object that you want to convert to a JSON
+ * string and then download as a file.
+ */
+function downloadJSON(filename, jsonData) {
+  const jsonString = JSON.stringify(jsonData, null, 2); // JSON in einen formatierten String umwandeln
+  const blob = new Blob([jsonString], { type: "application/json" });
+  const url = URL.createObjectURL(blob);
+
+  const a = document.createElement("a");
+  a.href = url;
+  a.download = filename;
+  document.body.appendChild(a);
+  a.click();
+  document.body.removeChild(a);
+  URL.revokeObjectURL(url);
+}
+
+
+function resizeImage(file, callback) {
+  const reader = new FileReader();
+  reader.readAsDataURL(file);
+  
+  reader.onload = function (event) {
+      const img = new Image();
+      img.src = event.target.result;
+      
+      img.onload = function () {
+          const canvas = document.createElement("canvas");
+          const ctx = canvas.getContext("2d");
+          
+          const maxWidth = 800;
+          const maxHeight = 800;
+          let width = img.width;
+          let height = img.height;
+          
+          if (width > maxWidth || height > maxHeight) {
+              const aspectRatio = width / height;
+              if (width > height) {
+                  width = maxWidth;
+                  height = width / aspectRatio;
+              } else {
+                  height = maxHeight;
+                  width = height * aspectRatio;
+              }
+          }
+          
+          canvas.width = width;
+          canvas.height = height;
+          ctx.drawImage(img, 0, 0, width, height);
+          
+          const base64String = canvas.toDataURL("image/jpeg", 0.8);
+          callback(base64String);
+      };
+  };
+}
