@@ -629,13 +629,50 @@ let comp = setInterval(() => {
   }, 1500);
 
 
+  function DownladCPBackup(){
+    downloadJSON('Velometrik_Custom_Protocol.dat', customJSN)
+  }
+
+  function UploadCPBackup() {
+    const input = document.createElement("input");
+    input.type = "file";
+    input.accept = ".dat,.json"; // Optional: Beschränkung auf bestimmte Dateitypen
+
+    input.addEventListener("change", function(event) {
+        const file = event.target.files[0];
+        if (!file) return;
+
+        const reader = new FileReader();
+        reader.onload = function(e) {
+            try {
+                const jsonData = JSON.parse(e.target.result);
+                customJSN = jsonData; // Speichert die geladene JSON-Datei in der Variable
+                saveCostomJSN()
+                renderCategoryView()
+                console.log("Backup erfolgreich hochgeladen:", customJSN);
+                alert("Backup erfolgreich hochgeladen!");
+            } catch (error) {
+                console.error("Fehler beim Parsen der Datei:", error);
+                alert("Fehler: Ungültiges JSON-Format!");
+            }
+        };
+
+        reader.readAsText(file);
+    });
+
+    input.click(); // Öffnet den Datei-Dialog
+}
 
   //SORT AND EDIT CUSTOM PROTOCOL INFORMATIONEN
   function renderCategoryView() {
     let container = document.getElementById("costom_protocol_holder");
     container.innerHTML = "";
 
-    newElement({ element: "h2", cls: ["uk-modal-title"], attr: [["key", "my_cat"]] }, container).innerHTML = "<!--Cat-->";
+    let div = newElement({element:"div",attr:[['style','display: flex;align-items: center;justify-content: space-between;']]},container)
+    newElement({ element: "h2", cls: ["uk-modal-title"], attr: [["key", "my_cat"]] }, div).innerHTML = "<!--Cat-->";
+    let div2 = newElement({element:"div"},div)
+    newElement({element:"button",cls:['uk-button','uk-button-primary','mdi','mdi-24px','mdi-download'],attr:[['onclick','DownladCPBackup()']]},div2)
+    newElement({element:"button",cls:['uk-button','uk-button-primary','mdi','mdi-24px','uk-margin-left','mdi-upload'],attr:[['onclick','UploadCPBackup()']]},div2)
     
     let divControls = newElement({ element: "div", cls: ["uk-margin"], attr: [["style", "display: flex;justify-content: space-between;align-items: center;align-content: flex-start;flex-direction: row;"]] }, container);
     newElement({ element: "input", id: "new-category", cls: ["uk-input"], attr: [["key-place", "sys_set_cat_name"]] }, divControls);
@@ -648,10 +685,10 @@ let comp = setInterval(() => {
         let li = newElement({ element: "li" }, ul);
         let div = newElement({ element: "div", cls: ["uk-card", "uk-card-default", "uk-card-body", "uk-text-center", "flex-between"] }, li);
         newElement({ element: "span", cls: ["uk-sortable-handle"], attr: [["uk-icon", "icon: table"]] }, div);
-        newElement({ element: "a", attr: [["onclick", `renderFieldView('${category}')`]] }, div).innerHTML = category;
-        let divButtons = newElement({ element: "div" }, div);
+        let divButtons = newElement({ element: "div",attr:[['style','display: flex;align-items: center;']] }, div);
+        newElement({ element: "a", attr: [["onclick", `renderFieldView('${category}')`]] }, divButtons).innerHTML = category;
         newElement({ element: "button", cls: ["uk-button", "uk-button-default", "uk-button-small", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-pencil-box-outline"], attr: [["onclick", `renderFieldView('${category}')`]] }, divButtons);
-        newElement({ element: "button", cls: ["uk-button", "uk-button-error", "uk-button-small", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-trash-can-outline"], attr: [["onclick", `deleteCategory('${category}')`]] }, divButtons);
+        newElement({ element: "button", cls: ["uk-button", "uk-button-error", "uk-button-small", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-trash-can-outline"], attr: [["onclick", `deleteCategory('${category}')`]] }, div);
     });
 
     translatejs();
@@ -669,7 +706,7 @@ function renderFieldView(category) {
     let divControls = newElement({ element: "div", cls: ["uk-margin"], attr: [["style", "display: flex;justify-content: space-between;align-items: center;align-content: flex-start;flex-direction: row;"]] }, container);
     newElement({ element: "input", id: "new-field", cls: ["uk-input"], attr: [["key-place", "sys_new_field"], ["placeholder", "Neues Feld"]] }, divControls);
     newElement({ element: "button", cls: ["uk-button", "uk-button-primary", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-plus-box-outline"], attr: [["onclick", `addField('${category}')`]] }, divControls);
-    newElement({ element: "button", cls: ["uk-button", "uk-button-secondary", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-content-save"], attr: [["onclick", `saveFieldOrder('${category}')`]] }, divControls);
+    //newElement({ element: "button", cls: ["uk-button", "uk-button-secondary", "uk-margin-small-right", "mdi", "mdi-24px", "mdi-content-save"], attr: [["onclick", `saveFieldOrder('${category}')`]] }, divControls);
     newElement({ element: "button", cls: ["uk-button", "uk-button-secondary", "uk-margin-small-right"], attr: [["key", "btn_back"], ["onclick", "renderCategoryView()"]] }, divControls).innerHTML = "<!--back-->";
 
     let ul = newElement({ element: "ul", id: "field-list", cls: ["uk-grid-small", "uk-child-width-1-2"], attr: [["uk-sortable", "handle: .uk-card"], ["uk-grid", ""]] }, container);
@@ -812,6 +849,7 @@ function addCategory() {
     if (newCategory && !customJSN[newCategory]) {
         customJSN[newCategory] = [];
         renderCategoryView();
+        saveCategoryOrder();
     }
 }
 
@@ -857,6 +895,7 @@ function addField(category) {
     
     customJSN[category].push(newField);
     renderFieldView(category);
+    saveFieldOrder(category)
 }
 
 
