@@ -14,11 +14,12 @@
 # 13.01.2024 Siegmar Müller V 3.3 mit Recorder begonnen
 # 24.01.2024 Siegmar Müller V 3.2.2 fertig
 # 08.03.2024 Siegmar Müller V 3.3.0 (Recorder, App dekubitus) fertig
+# 08.03.2024 Siegmar Müller V 3.4 begonnen
 #
 
 # Die Versionsnummer bezieht sich auf das gesamte Paket (nicht nur auf diese Datei).
 # Gesondert versioniert sind die Apps und die htdocs.
-set ::VERSION "3.3.0"
+set ::VERSION "3.4.0"
 
 set ::dir [file dirname [info script]]
 if {[string equal -length 1 $::dir "."]} {
@@ -131,7 +132,7 @@ namespace eval ::VELOBOX_CONF {
     if {[file exists /usr/local/etc/velobox.conf]} {
         readVeloboxConf /usr/local/etc/velobox.conf
     }
-}
+}; # namespace eval ::VELOBOX_CONF
 #}}} Velobox Konfiguration
 
 # Hilfe ausgeben und beenden
@@ -667,7 +668,7 @@ namespace eval ::wscomm {; #{{{
     proc execWsRequest {request lquery datavar} {; #{{{
         upvar $datavar data
 
-        set parameter "[::http::formatQuery {*}[join $lquery " "]]"
+        set parameter "[::http::formatQuery {*}$lquery]"
         if {[catch {
             srvLog {} Debug "Encrypting $parameter"
             set encrypted [vmkcrypt encrypt $parameter]
@@ -739,6 +740,62 @@ namespace eval ::wscomm {; #{{{
                             }
                         }
                     }
+                    # Ab Webservice Version 1.6 nimmt dieser die Features und die Konfiguration der Velobox entgegen.
+                    if {[regsub {^([0-9]+\.[0-9]+).*$} $::WS_VERSION {\1} ws_version] == 1} {
+                        if {$ws_version >= 1.6} {
+                            srvLog {inetcheck} Debug "Webservice Version >= 1.6"
+                            # => features senden
+                            set hardware [list]
+                            foreach hwkomp [split $::VELOBOX_CONF::HARDWARE ","] {
+                                lappend hardware \"[string map {\" \\\"} $hwkomp]\"
+                            }
+                            set apps [list]
+                            foreach appcode [dict keys $::apps::apps_loaded] {
+                                lappend apps $appcode
+                                if [info exists ::apps::${appcode}::VERSION] {
+                                    lappend apps [set ::apps::${appcode}::VERSION]
+                                } else {
+                                    lappend apps "0.0.0"
+                                }
+                            }
+                            set json_apps [list]
+                            foreach {app version} $apps {
+                                lappend json_apps "{\"${app}\": \"$version\"}"
+                            }
+                            set features "\{\
+                                \"VERSION\": \"$::VELOBOX_CONF::VERSION\",\
+                                \"HARDWARE\": \[[join $hardware {, }]\],\
+                                \"apps\": \[[join $json_apps {, }]\]\
+                                \}"
+                            if {[execWsRequest set [list station_nr $::STATION_NR what features value "$features"] wsAntwort]} {
+                                srvLog {inetcheck} Debug "Webservice antwortet auf /set features mit \"$wsAntwort\"."
+                                #TODO evtl. Fehler => entsprechendes srvLog
+                            }
+                            set htdocs "{}"
+                            if {[file exists ${::dir}/htdocs/htdocs.json]} {
+                                set fd [open ${::dir}/htdocs/htdocs.json r]
+                                set json_htdocs [read $fd]
+                                close $fd
+                                if {[catch {::json::json2dict $json_htdocs}]} {
+                                    srvLog {inetcheck} Error $result
+                                } else {
+                                    set htdocs [string map {"\n" ""} $json_htdocs]
+                                }
+                            }
+                            set konfiguration "\{\
+                                \"LANG\": \"$::VELOBOX_CONF::LANG\",\
+                                \"DOWNLOADSERVER\": \"$::VELOBOX_CONF::DOWNLOADSERVER\",\
+                                \"UPDATEDIR\": \"$::VELOBOX_CONF::UPDATEDIR\",\
+                                \"USAGE\": \"$::VELOBOX_CONF::USAGE\",\
+                                \"IMPLEMENTATION\": \"$::VELOBOX_CONF::IMPLEMENTATION\",\
+                                \"htdocs\": $htdocs\
+                                \}"
+                            if {[execWsRequest set [list station_nr $::STATION_NR what konfiguration value "$konfiguration"] wsAntwort]} {
+                                srvLog {inetcheck} Debug "Webservice antwortet auf /set konfiguration mit \"$wsAntwort\"."
+                                #TODO evtl. Fehler => entsprechendes srvLog
+                            }
+                        }
+                    }
                 } else {; # Webservice antwortet nicht
                     srvLog {inetcheck} Warn "Webservice nicht verfügbar"
                     set webservice_verfuegbar 0
